@@ -25,6 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QPushButton>
+#include <QtCore/qmath.h>
 
 // KDE
 #include <KDebug>
@@ -74,6 +75,16 @@ struct CropWidgetPrivate : public Ui_CropWidget
 
     double cropRatio() const
     {
+        int index = ratioComboBox->currentIndex();
+        if (index != -1 && ratioComboBox->currentText() == ratioComboBox->itemText(index)) {
+            // Get ratio from predefined value
+            // Note: We check currentText is itemText(currentIndex) because
+            // currentIndex is not reset to -1 when text is edited by hand.
+            QSizeF size = ratioComboBox->itemData(index).toSizeF();
+            return size.height() / size.width();
+        }
+
+        // Not a predefined value, extract ratio from the combobox text
         const QStringList lst = ratioComboBox->currentText().split(':');
         if (lst.size() != 2) {
             return 0;
@@ -92,41 +103,56 @@ struct CropWidgetPrivate : public Ui_CropWidget
         return height / width;
     }
 
-    void addRatioToComboBox(const QSize& size, const QString& label = QString())
+    void addRatioToComboBox(const QSizeF& size, const QString& label = QString())
     {
-        QString text = QString("%1:%2").arg(size.width()).arg(size.height());
-        if (!label.isEmpty()) {
-            text += QString(" (%1)").arg(label);
-        }
+        QString text = label.isEmpty()
+            ? QString("%1:%2").arg(size.width()).arg(size.height())
+            : label;
         ratioComboBox->addItem(text, QVariant(size));
     }
 
-    void addSeparatorToComboBox()
+    void addSectionHeaderToComboBox(const QString& title)
     {
+        // Insert a line
         ratioComboBox->insertSeparator(ratioComboBox->count());
+
+        // Insert our section header
+        // This header is made of a separator with a text. We reset
+        // Qt::AccessibleDescriptionRole to the header text otherwise QComboBox
+        // delegate will draw a separator line instead of our text.
+        int index = ratioComboBox->count();
+        ratioComboBox->insertSeparator(index);
+        ratioComboBox->setItemText(index, title);
+        ratioComboBox->setItemData(index, title, Qt::AccessibleDescriptionRole);
+        ratioComboBox->setItemData(index, Qt::AlignHCenter, Qt::TextAlignmentRole);
     }
 
     void initRatioComboBox()
     {
-        QList<QSize> ratioList;
+        QList<QSizeF> ratioList;
+        const qreal sqrt2 = qSqrt(2.);
         ratioList
-                << QSize(3, 2)
-                << QSize(4, 3)
-                << QSize(5, 4)
-                << QSize(7, 5);
+                << QSizeF(7, 5)
+                << QSizeF(3, 2)
+                << QSizeF(4, 3)
+                << QSizeF(5, 4);
 
-        addRatioToComboBox(QSize(1, 1), i18n("Square"));
+        addRatioToComboBox(QSizeF(1, 1), i18n("Square"));
         addRatioToComboBox(screenRatio(), i18n("This Screen"));
-        addSeparatorToComboBox();
+        addSectionHeaderToComboBox(i18n("Landscape"));
 
-        Q_FOREACH(const QSize & size, ratioList) {
+        Q_FOREACH(const QSizeF& size, ratioList) {
             addRatioToComboBox(size);
         }
-        addSeparatorToComboBox();
-        Q_FOREACH(QSize size, ratioList) {
+        addRatioToComboBox(QSizeF(sqrt2, 1), i18n("ISO Size (A4, A3...)"));
+        addRatioToComboBox(QSizeF(11, 8.5), i18n("US Letter"));
+        addSectionHeaderToComboBox(i18n("Portrait"));
+        Q_FOREACH(QSizeF size, ratioList) {
             size.transpose();
             addRatioToComboBox(size);
         }
+        addRatioToComboBox(QSizeF(1, sqrt2), i18n("ISO Size (A4, A3...)"));
+        addRatioToComboBox(QSizeF(8.5, 11), i18n("US Letter"));
 
         ratioComboBox->setMaxVisibleItems(ratioComboBox->count());
         ratioComboBox->setEditText(QString());
@@ -208,8 +234,6 @@ CropWidget::CropWidget(QWidget* parent, RasterImageView* imageView, CropTool* cr
 
     connect(d->ratioComboBox, SIGNAL(editTextChanged(QString)),
             SLOT(slotRatioComboBoxEditTextChanged()));
-    connect(d->ratioComboBox, SIGNAL(activated(int)),
-            SLOT(slotRatioComboBoxActivated()));
 
     // Don't do this before signals are connected, otherwise the tool won't get
     // initialized
@@ -291,16 +315,4 @@ void CropWidget::slotRatioComboBoxEditTextChanged()
     applyRatioConstraint();
 }
 
-void CropWidget::slotRatioComboBoxActivated()
-{
-    // If the ratioComboBox contains text like this: "w:h (foo bar)", change it
-    // to "w:h" only, so that it's easier to edit for the user.
-    QStringList lst = d->ratioComboBox->currentText().split(' ');
-    if (lst.size() > 1) {
-        SignalBlocker blocker(d->ratioComboBox);
-        d->ratioComboBox->setEditText(lst[0]);
-        applyRatioConstraint();
-    }
-}
-
 } // namespace
