@@ -265,7 +265,10 @@ Orientation JpegContent::orientation() const
 {
     Exiv2::ExifKey key("Exif.Image.Orientation");
     Exiv2::ExifData::iterator it = d->mExifData.findKey(key);
-    if (it == d->mExifData.end()) {
+
+    // We do the same checks as in libexiv2's src/crwimage.cpp:
+    // http://dev.exiv2.org/projects/exiv2/repository/entry/trunk/src/crwimage.cpp?rev=2681#L1336
+    if (it == d->mExifData.end() || it->count() == 0 || it->typeId() != Exiv2::unsignedShort) {
         return NOT_AVAILABLE;
     }
     return Orientation(it->toLong());
